@@ -9,6 +9,7 @@ import warnings
 import matplotlib.pyplot as plt
 import numpy as np
 import xarray as xr
+import inspect
 
 
 class Display:
@@ -278,3 +279,144 @@ class Display:
         self.cbs.append(cbar)
 
         return cbar
+
+    def group_by(self, units):
+        """
+        Group the Display by specific units of time.
+
+        Parameters
+        ----------
+        units: str
+            One of: 'year', 'month', 'day', 'hour', 'minute', 'second'.
+            Group the plot by this unit of time (year, month, etc.)
+        Returns
+        -------
+        groupby: act.plotting.DisplayGroupby
+            The DisplayGroupby object to be retuned.
+        """
+        return DisplayGroupby(self, units)
+
+
+class DisplayGroupby(object):
+    def __init__(self, display, units):
+        """
+
+        Parameters
+        ----------
+        display: Display
+            The Display object to group by time.
+        units: str
+            The time units to group by. Can be one of:
+            'year', 'month', 'day', 'hour', 'minute', 'second'
+        """
+        self.display = display
+        self._groupby = {}
+        self.mapping = {}
+        self.xlims = {}
+        self.units = units
+        self.isTimeSeriesDisplay = hasattr(self.display, 'time_height_scatter')
+        num_groups = 0
+        datastreams = list(display._obj.keys())
+        for key in datastreams:
+            self._groupby[key] = display._obj[key].groupby('time.%s' % units)
+            num_groups = max([num_groups, len(self._groupby[key])])
+
+    def plot_group(self, func_name, dsname=None, **kwargs):
+        """
+        Plots each group created in :func:`act.plotting.Display.group_by` into each subplot of the display.
+        Parameters
+        ----------
+        func_name: str
+            The name of the plotting function in the Display that you are grouping.
+        dsname: str or None
+            The name of the datastream to plot
+
+        Additional keyword objects are passed into *func_name*.
+
+        Returns
+        -------
+        axis: Array of matplotlib axes handles
+            The array of matplotlib axes handles that correspond to each subplot.
+        """
+        if dsname is None:
+            dsname = list(self.display._obj.keys())[0].split('_')[0]
+
+        func = getattr(self.display, func_name)
+
+        if not callable(func):
+            raise RuntimeError("The specified string is not a function of "
+                               "the Display object.")
+        subplot_shape = self.display.axes.shape
+        i = 0
+        wrap_around = False
+        old_obj = self.display._obj
+        for key in self._groupby.keys():
+            if dsname == key:
+                self.display._obj = {}
+                for k, ds in self._groupby[key]:
+                    num_years = len(np.unique(ds.time.dt.year))
+                    self.display._obj[key + '_%d' % k] = ds
+                    if i >= np.prod(subplot_shape):
+                        i = 0
+                        wrap_around = True
+                    if len(subplot_shape) == 2:
+                        subplot_index = (int(i / subplot_shape[1]), i % subplot_shape[1])
+                    else:
+                        subplot_index = (i % subplot_shape[0],)
+                    args, varargs, varkw, _, _, _, _ = inspect.getfullargspec(func)
+                    if "subplot_index" in args:
+                        kwargs["subplot_index"] = subplot_index
+                    if "time_rng" in args:
+                        kwargs["time_rng"] = (ds.time.values.min(), ds.time.values.max())
+                    if num_years > 1 and self.isTimeSeriesDisplay:
+                        first_year = ds.time.dt.year[0]
+                        for yr, ds1 in ds.groupby('time.year'):
+                            if ds1.time.dt.year[0] % 4 == 0:
+                                days_in_year = 366
+                            else:
+                                days_in_year = 365
+                            year_diff = ds1.time.dt.year - first_year
+                            time_diff = np.array(
+                                [np.timedelta64(x * days_in_year, 'D') for x in year_diff.values])
+                            ds1['time'] = ds1.time - time_diff
+                            self.display._obj[key + '%d_%d' % (k, yr)] = ds1
+                            func(dsname=key + '%d_%d' % (k, yr), label=str(yr), **kwargs)
+                            self.mapping[key + '%d_%d' % (k, yr)] = subplot_index
+                            self.xlims[key + '%d_%d' % (k, yr)] = (ds1.time.values.min(), ds1.time.values.max())
+                        del self.display._obj[key + '_%d' % k]
+                    else:
+                        func(dsname=key + '_%d' % k, **kwargs)
+                        self.mapping[key + '_%d' % k] = subplot_index
+                        if self.isTimeSeriesDisplay:
+                            self.xlims[key + '_%d' % k] = (ds.time.values.min(), ds.time.values.max())
+                    i = i + 1
+
+        if wrap_around is False and i < np.prod(subplot_shape):
+            while i < np.prod(subplot_shape):
+                if len(subplot_shape) == 2:
+                    subplot_index = (int(i / subplot_shape[1]), i % subplot_shape[1])
+                else:
+                    subplot_index = (i % subplot_shape[0],)
+                self.display.axes[subplot_index].axis('off')
+                i = i + 1
+
+        for i in range(1, np.prod(subplot_shape)):
+            if len(subplot_shape) == 2:
+                subplot_index = (int(i / subplot_shape[1]), i % subplot_shape[1])
+            else:
+                subplot_index = (i % subplot_shape[0],)
+            try:
+                self.display.axes[subplot_index].get_legend().remove()
+            except AttributeError:
+                pass
+
+        if self.isTimeSeriesDisplay:
+            key_list = list(self.display._obj.keys())
+            for k in key_list:
+                time_min, time_max = self.xlims[k]
+                subplot_index = self.mapping[k]
+                self.display.set_xrng([time_min, time_max], subplot_index)
+
+        self.display._obj = old_obj
+
+        return self.display.axes
