@@ -72,8 +72,7 @@ class XSectionDisplay(Display):
     """
 
     def __init__(self, obj, subplot_shape=(1,), ds_name=None, **kwargs):
-        super().__init__(obj, None, ds_name, **kwargs)
-        self.add_subplots(subplot_shape)
+        super().__init__(obj, subplot_shape, ds_name, **kwargs)
 
     def set_subplot_to_map(self, subplot_index):
         total_num_plots = self.axes.shape
